Clojure only.

k16.glitch.metamerge


meta-mergeclj

(meta-merge)
(meta-merge left)
(meta-merge left right)
(meta-merge left right & more)

Recursively merge values based on the information in their metadata.

Recursively merge values based on the information in their metadata.
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries